define(["exports", "../l10n"], function (exports, _l10n) {
  "use strict";

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.lint = lint;

  var _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  var rule = "no-headingless-sections";

  var meta = {
    en: {
      description: "All sections must start with a `h2-6` element.",
      howToFix: "Add a `h2-6` to the offending section or use a `<div>`.",
      help: "See developer console."
    }
  };
  // Fall back to english, if language is missing
  var lang = _l10n.lang in meta ? _l10n.lang : "en";

  var hasNoHeading = function hasNoHeading(_ref) {
    var elem = _ref.firstElementChild;

    return elem === null || /^h[1-6]$/.test(elem.localName) === false;
  };

  function lint(_ref2) {
    var doc = _ref2.doc;

    var result = [];
    var offendingElements = Array.from(doc.querySelectorAll("section")).filter(hasNoHeading);
    if (offendingElements.length) {
      result.push(_extends({
        rule: rule,
        offendingElements: offendingElements,
        occurances: offendingElements.length
      }, meta[lang]));
    }
    return result;
  }
});
//# sourceMappingURL=no-headingless-sections.js.map