define(["exports", "core/l10n"], function (exports, _l10n) {
  "use strict";

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.lint = lint;

  var _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  var _templateObject = _taggedTemplateLiteral(["Please change the following properties to 'https://': ", "."], ["Please change the following properties to 'https://': ", "."]);

  function _taggedTemplateLiteral(strings, raw) {
    return Object.freeze(Object.defineProperties(strings, {
      raw: {
        value: Object.freeze(raw)
      }
    }));
  }

  var _slicedToArray = function () {
    function sliceIterator(arr, i) {
      var _arr = [];
      var _n = true;
      var _d = false;
      var _e = undefined;

      try {
        for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
          _arr.push(_s.value);

          if (i && _arr.length === i) break;
        }
      } catch (err) {
        _d = true;
        _e = err;
      } finally {
        try {
          if (!_n && _i["return"]) _i["return"]();
        } finally {
          if (_d) throw _e;
        }
      }

      return _arr;
    }

    return function (arr, i) {
      if (Array.isArray(arr)) {
        return arr;
      } else if (Symbol.iterator in Object(arr)) {
        return sliceIterator(arr, i);
      } else {
        throw new TypeError("Invalid attempt to destructure non-iterable instance");
      }
    };
  }();

  var rule = "no-https-props";
  var offendingMembers = [];

  function howToFix(_ref, offendingMembers) {
    var _ref2 = _slicedToArray(_ref, 2),
        start = _ref2[0],
        end = _ref2[1];

    var items = offendingMembers.map(function (item) {
      return "`" + item + "`";
    }).join(",");
    return start + items + end;
  }

  var meta = {
    en: {
      description: "Insecure URLs are not allowed in `respecConfig`.",
      get howToFix() {
        return howToFix(_templateObject, offendingMembers);
      }
    }
  };

  // Fall back to english, if language is missing
  var lang = _l10n.lang in meta ? _l10n.lang : "en";

  function lint(_ref3) {
    var conf = _ref3.conf,
        doc = _ref3.doc;

    // We can only really perform this check over http/https
    if (!doc.location.href.startsWith("http")) {
      return;
    }
    Object.getOwnPropertyNames(conf
    // this check is cheap, "prevED" is w3c exception.
    ).filter(function (key) {
      return key.endsWith("URI") || key === "prevED";
    }
    // this check is expensive, so seperate step
    ).filter(function (key) {
      return new URL(conf[key], doc.location.href).href.startsWith("http://");
    }).reduce(function (collector, key) {
      return offendingMembers.push(key);
    }, offendingMembers);
    var result = [];
    if (offendingMembers.length) {
      result.push(_extends({
        rule: rule,
        occurances: offendingMembers.length
      }, meta[lang]));
    }
    return result;
  }
});
//# sourceMappingURL=no-http-props.js.map