define(["exports", "core/pubsubhub", "core/linter-rules/no-http-props", "core/linter-rules/no-headingless-sections"], function (exports, _pubsubhub, _noHttpProps, _noHeadinglessSections) {
  "use strict";

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.run = exports.name = undefined;

  var _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  function _toConsumableArray(arr) {
    if (Array.isArray(arr)) {
      for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) {
        arr2[i] = arr[i];
      }

      return arr2;
    } else {
      return Array.from(arr);
    }
  }

  function _asyncToGenerator(fn) {
    return function () {
      var gen = fn.apply(this, arguments);
      return new Promise(function (resolve, reject) {
        function step(key, arg) {
          try {
            var info = gen[key](arg);
            var value = info.value;
          } catch (error) {
            reject(error);
            return;
          }

          if (info.done) {
            resolve(value);
          } else {
            return Promise.resolve(value).then(function (value) {
              step("next", value);
            }, function (err) {
              step("throw", err);
            });
          }
        }

        return step("next");
      });
    };
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  var _createClass = function () {
    function defineProperties(target, props) {
      for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];
        descriptor.enumerable = descriptor.enumerable || false;
        descriptor.configurable = true;
        if ("value" in descriptor) descriptor.writable = true;
        Object.defineProperty(target, descriptor.key, descriptor);
      }
    }

    return function (Constructor, protoProps, staticProps) {
      if (protoProps) defineProperties(Constructor.prototype, protoProps);
      if (staticProps) defineProperties(Constructor, staticProps);
      return Constructor;
    };
  }();

  var name = exports.name = "core/linter";

  var privates = new WeakMap();

  var Linter = function () {
    function Linter() {
      _classCallCheck(this, Linter);

      privates.set(this, {
        rules: new Set()
      });
    }

    _createClass(Linter, [{
      key: "register",
      value: function register() {
        for (var _len = arguments.length, newRules = Array(_len), _key = 0; _key < _len; _key++) {
          newRules[_key] = arguments[_key];
        }

        newRules.reduce(function (rules, newRule) {
          return rules.add(newRule);
        }, this.rules);
      }
    }, {
      key: "lint",
      value: function () {
        var _ref = _asyncToGenerator(regeneratorRuntime.mark(function _callee2(conf) {
          var _this = this;

          var doc = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : window.document;
          var promisesToLint, results;
          return regeneratorRuntime.wrap(function _callee2$(_context2) {
            while (1) {
              switch (_context2.prev = _context2.next) {
                case 0:
                  promisesToLint = [].concat(_toConsumableArray(privates.get(this).rules)).map(function () {
                    var _ref2 = _asyncToGenerator(regeneratorRuntime.mark(function _callee(lint) {
                      return regeneratorRuntime.wrap(function _callee$(_context) {
                        while (1) {
                          switch (_context.prev = _context.next) {
                            case 0:
                              _context.next = 2;
                              return lint({ doc: doc, conf: conf });

                            case 2:
                              return _context.abrupt("return", _context.sent);

                            case 3:
                            case "end":
                              return _context.stop();
                          }
                        }
                      }, _callee, _this);
                    }));

                    return function (_x3) {
                      return _ref2.apply(this, arguments);
                    };
                  }());
                  _context2.next = 3;
                  return Promise.all(promisesToLint);

                case 3:
                  results = _context2.sent;
                  return _context2.abrupt("return", results.reduce(function (collector, results) {
                    return collector.concat(results);
                  }, []));

                case 5:
                case "end":
                  return _context2.stop();
              }
            }
          }, _callee2, this);
        }));

        function lint(_x2) {
          return _ref.apply(this, arguments);
        }

        return lint;
      }()
    }, {
      key: "rules",
      get: function get() {
        return privates.get(this).rules;
      }
    }]);

    return Linter;
  }();

  var linter = new Linter();
  linter.register(_noHttpProps.lint, _noHeadinglessSections.lint);

  exports.default = linter;


  var baseResult = {
    rule: "unknown",
    description: "",
    occurances: 0,
    howToFix: "",
    offendingElements: [], // DOM Nodes
    help: "" // where to get help
  };

  var run = exports.run = function () {
    var _ref3 = _asyncToGenerator(regeneratorRuntime.mark(function _callee3(conf, doc, cb) {
      var results;
      return regeneratorRuntime.wrap(function _callee3$(_context3) {
        while (1) {
          switch (_context3.prev = _context3.next) {
            case 0:
              if (!(conf.lint === false)) {
                _context3.next = 3;
                break;
              }

              cb(); // return early, don't do anything
              return _context3.abrupt("return");

            case 3:
              cb(); // continue other processing
              _context3.next = 6;
              return document.respecReady;

            case 6:
              _context3.next = 8;
              return linter.lint(conf);

            case 8:
              results = _context3.sent;

              results.map(function (result) {
                var output = _extends({}, baseResult, result);
                var description = output.description,
                    occurances = output.occurances,
                    rule = output.rule,
                    howToFix = output.howToFix,
                    help = output.help,
                    offendingElements = output.offendingElements;

                var msg = description + " " + howToFix + " " + help;
                offendingElements.forEach(function (elem) {
                  var _console;

                  elem.classList.add("respec-offending-element");
                  (_console = console).warn.apply(_console, [rule, description].concat(_toConsumableArray(offendingElements)));
                });
                return msg.trim();
              }).forEach(function (msg) {
                (0, _pubsubhub.pub)("warn", msg);
              });

            case 10:
            case "end":
              return _context3.stop();
          }
        }
      }, _callee3, this);
    }));

    return function run(_x4, _x5, _x6) {
      return _ref3.apply(this, arguments);
    };
  }();
});
//# sourceMappingURL=linter.js.map