define(["exports"], function (exports) {
  "use strict";

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.run = run;

  var _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  /**
   * Sets the defaults for W3C specs
   */
  var name = exports.name = "w3c/defaults";
  var cgbg = new Set(["CG-DRAFT", "CG-FINAL", "BG-DRAFT", "BG-FINAL"]);
  var licenses = new Map([["cc0", {
    name: "Creative Commons 0 Public Domain Dedication",
    short: "CC0",
    url: "https://creativecommons.org/publicdomain/zero/1.0/"
  }], ["w3c-software", {
    name: "W3C Software Notice and License",
    short: "W3C Software",
    url: "https://www.w3.org/Consortium/Legal/2002/copyright-software-20021231"
  }], ["w3c-software-doc", {
    name: "W3C Software and Document Notice and License",
    short: "W3C Software and Document",
    url: "https://www.w3.org/Consortium/Legal/2015/copyright-software-and-document"
  }], ["cc-by", {
    name: "Creative Commons Attribution 4.0 International Public License",
    short: "CC-BY",
    url: "https://creativecommons.org/licenses/by/4.0/legalcode"
  }]]);

  var w3cDefaults = {
    processVersion: 2017,
    lint: true,
    doRDFa: false,
    license: "w3c-software-doc",
    specStatus: "base",
    logos: [{
      id: "",
      alt: "W3C",
      href: "https://www.w3.org/",
      src: "https://www.w3.org/StyleSheets/TR/2016/logos/W3C",
      height: "48",
      width: "72"
    }]
  };

  function validateConf(conf) {
    var errors = [];
    var warnings = [];
    if (!conf.hasOwnProperty("specStatus")) {
      errors.push("Missing required configuration: `specStatus`");
    }
    if (conf.isRegular && !conf.shortName) {
      errors.push("Missing required configuration: `shortName`");
    }
    return { errors: errors, warnings: warnings };
  }

  function run(conf) {
    debugger;
    // assign the defaults
    Object.assign(conf, _extends({}, w3cDefaults, conf));
    //computed properties
    Object.defineProperties(conf, {
      isCCBY: {
        get: function get() {
          return conf.license === "cc-by";
        }
      },
      licenseInfo: {
        get: function get() {
          return licenses.get(conf.license);
        }
      },
      isCGBG: {
        get: function get() {
          return cgbg.has(conf.specStatus);
        }
      },
      isCGFinal: {
        get: function get() {
          return conf.isCGBG && /G-FINAL$/.test(conf.specStatus);
        }
      },
      isBasic: {
        get: function get() {
          return conf.specStatus === "base";
        }
      },
      isRegular: {
        get: function get() {
          return !conf.isCGBG && !conf.isBasic;
        }
      }
    });
  }
});
//# sourceMappingURL=defaults.js.map