define(["exports", "../l10n"], function (exports, _l10n) {
  "use strict";

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.lint = lint;

  var _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  var rule = "privsec-section";

  var meta = {
    en: {
      description: "Document must a Privacy and/or Security Considerations section.",
      howToFix: "Add a privacy and/or security considerations section.",
      help: "See the [Self-Review Questionnaire](https://w3ctag.github.io/security-questionnaire/)."
    }
  };

  // Fall back to english, if language is missing
  var lang = _l10n.lang in meta ? _l10n.lang : "en";

  function hasPriSecConsiderations(doc) {
    var privOrSecRegex = /(privacy|security)/im;
    var considerationsRegex = /(considerations)/im;
    return Array.from(doc.querySelectorAll("h2, h3, h4, h5, h6")).some(function (_ref) {
      var text = _ref.textContent;

      var saysPrivOrSec = privOrSecRegex.test(text);
      var saysConsiderations = considerationsRegex.test(text);
      return saysPrivOrSec && saysConsiderations || saysPrivOrSec;
    });
  }

  function lint(_ref2) {
    var doc = _ref2.doc,
        conf = _ref2.conf;

    var result = [];
    if (conf.isRecTrack && !hasPriSecConsiderations(doc)) {
      result.push(_extends({
        rule: rule,
        occurrances: 1
      }, meta[lang]));
    }
    return result;
  }
});
//# sourceMappingURL=privsec-section.js.map