/**
 * Sets the defaults for W3C specs
 */
export const name = "w3c/defaults";
const cgbg = new Set(["CG-DRAFT", "CG-FINAL", "BG-DRAFT", "BG-FINAL"]);
const licenses = new Map([
  [
    "cc0",
    {
      name: "Creative Commons 0 Public Domain Dedication",
      short: "CC0",
      url: "https://creativecommons.org/publicdomain/zero/1.0/",
    },
  ],
  [
    "w3c-software",
    {
      name: "W3C Software Notice and License",
      short: "W3C Software",
      url:
        "https://www.w3.org/Consortium/Legal/2002/copyright-software-20021231",
    },
  ],
  [
    "w3c-software-doc",
    {
      name: "W3C Software and Document Notice and License",
      short: "W3C Software and Document",
      url:
        "https://www.w3.org/Consortium/Legal/2015/copyright-software-and-document",
    },
  ],
  [
    "cc-by",
    {
      name: "Creative Commons Attribution 4.0 International Public License",
      short: "CC-BY",
      url: "https://creativecommons.org/licenses/by/4.0/legalcode",
    },
  ],
]);

const w3cDefaults = {
  processVersion: 2017,
  lint: true,
  doRDFa: false,
  license: "w3c-software-doc",
  specStatus: "base",
  logos: [
    {
      id: "",
      alt: "W3C",
      href: "https://www.w3.org/",
      src: "https://www.w3.org/StyleSheets/TR/2016/logos/W3C",
      height: "48",
      width: "72",
    },
  ],
};

function validateConf(conf) {
  const errors = [];
  const warnings = [];
  if (!conf.hasOwnProperty("specStatus")) {
    errors.push("Missing required configuration: `specStatus`");
  }
  if (conf.isRegular && !conf.shortName) {
    errors.push("Missing required configuration: `shortName`");
  }
  return { errors, warnings };
}

export function run(conf) {
  debugger;
  // assign the defaults
  Object.assign(conf, { ...w3cDefaults, ...conf });
  //computed properties
  Object.defineProperties(conf, {
    isCCBY: {
      get() {
        return conf.license === "cc-by";
      },
    },
    licenseInfo: {
      get() {
        return licenses.get(conf.license);
      },
    },
    isCGBG: {
      get() {
        return cgbg.has(conf.specStatus);
      },
    },
    isCGFinal: {
      get() {
        return conf.isCGBG && /G-FINAL$/.test(conf.specStatus);
      },
    },
    isBasic: {
      get() {
        return conf.specStatus === "base";
      },
    },
    isRegular: {
      get() {
        return !conf.isCGBG && !conf.isBasic;
      },
    },
  });
}
